﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace HandBrakeInteropExample
{
	using System.IO;
	using System.Xml.Serialization;
	using HandBrake.Interop;
	using HandBrake.Interop.Model;
	using HandBrake.Interop.Model.Encoding;

	class Program
	{
		private static HandBrakeInstance instance;
		private const string SourceFile = @"D:\videos\Left 4 Dead 2 Intro.mp4";

		static void Main(string[] args)
		{
			instance = new HandBrakeInstance();
			instance.Initialize(verbosity: 1);
			instance.ScanCompleted += instance_ScanCompleted;
			instance.StartScan(SourceFile, previewCount: 10);

			Console.ReadLine();
		}

		static void instance_ScanCompleted(object sender, EventArgs e)
		{
			Console.WriteLine("Scan complete");

			var serializer = new XmlSerializer(typeof(EncodingProfile));
			EncodingProfile profile;
			using (var stream = new FileStream("Normal.xml", FileMode.Open, FileAccess.Read))
			{
				profile = serializer.Deserialize(stream) as EncodingProfile;
			}

			var job = new EncodeJob
				{
					EncodingProfile = profile,
					RangeType = VideoRangeType.All,
					Title = 1,
					SourcePath = SourceFile,
					OutputPath = AppDomain.CurrentDomain.BaseDirectory + "Output.mp4",
					ChosenAudioTracks = new List<int> { 1 },
					Subtitles = new Subtitles
						{
							SourceSubtitles = new List<SourceSubtitle>(),
							SrtSubtitles = new List<SrtSubtitle>()
						}
				};

			instance.EncodeProgress += (o, args) =>
				{
					Console.WriteLine(args.FractionComplete);
				};
			instance.EncodeCompleted += (o, args) =>
				{
					Console.WriteLine("Encode completed.");
				};
			instance.StartEncode(job);
		}
	}
}
